# moyopy

[![CI](https://github.com/spglib/moyo/actions/workflows/ci-python.yaml/badge.svg)](https://github.com/spglib/moyo/actions/workflows/ci-python.yaml)
[![image](https://img.shields.io/pypi/l/moyopy.svg)](https://pypi.python.org/pypi/moyopy)
[![image](https://img.shields.io/pypi/v/moyopy.svg)](https://pypi.python.org/pypi/moyopy)
[![image](https://img.shields.io/pypi/pyversions/moyopy.svg)](https://pypi.python.org/pypi/moyopy)

Python interface of [moyo](https://github.com/spglib/moyo), a fast and robust crystal symmetry finder.

- Document: <https://spglib.github.io/moyo/python/>
- PyPI: <https://pypi.org/project/moyopy/>

## Installation

```shell
pip install moyopy
# If you want to convert structures into Pymatgen or ASE objects
pip install moyopy[interface]
```
